@@ -25,8 +25,6 @@ class SaveAppUtility:
                         if save_as:
                             if self.app_name == self.AppTemplateName:
                                 self.api_missing = True
-                                self.sandbox.automation_api.WriteMessageToReservationOutput(self.sandbox.id, "Stopping Save As because App's name was not changed prior to deployment.\n"
-                                                                                                             "Use the 'NewAppName' custom attribute on the command to override.")
                             else:
                                 self.new_app_name = self.app_name
                         else:
@@ -35,6 +33,9 @@ class SaveAppUtility:
                         self.new_app_name = new_app_name
                 except Exception as e:
                     self.new_app_name = self.app_name
+                if self.api_missing:
+                    raise Exception("Stopping Save As because App's name was not changed prior to deployment.\n"
+                                    "Use the 'NewAppName' custom attribute on the command to override.")
 
         self.server_address = server_address
         self.admin_user = admin_user
